@@ -46,11 +46,11 @@ prepanel.default.bwplot <-
                  if (stack) {
                      foo1 <-
                          if (any(x > 0))
-                             range( by(x[x > 0], y[x > 0, drop = TRUE], sum, na.rm = TRUE), finite = TRUE) 
+                             range(tapply(x[x > 0], y[x > 0, drop = TRUE], sum, na.rm = TRUE), finite = TRUE) 
                          else 0
                      foo2 <-
                          if (any(x < 0))
-                             range( by(x[x<0], y[x<0, drop = TRUE], sum, na.rm = TRUE), finite = TRUE) 
+                             range(tapply(x[x < 0], y[x < 0, drop = TRUE], sum, na.rm = TRUE), finite = TRUE) 
                          else 0
                      range(foo1, foo2)
                  }
@@ -74,11 +74,11 @@ prepanel.default.bwplot <-
                  if (stack) {
                      foo1 <-
                          if (any(y > 0))
-                             range( by(y[y > 0], x[y > 0], sum, na.rm = TRUE), finite = TRUE)
+                             range(tapply(y[y > 0], x[y > 0], sum, na.rm = TRUE), finite = TRUE)
                          else 0
                      foo2 <-
                          if (any(y < 0))
-                             range( by(y[y < 0], x[y < 0], sum, na.rm = TRUE), finite = TRUE)
+                             range(tapply(y[y < 0], x[y < 0], sum, na.rm = TRUE), finite = TRUE)
                          else 0
                      range(foo1, foo2)
                  }
@@ -98,7 +98,7 @@ prepanel.default.bwplot <-
 
 
 panel.barchart <-
-    function(x, y, box.ratio = 1,
+    function(x, y, box.ratio = 1, box.width = box.ratio / (1 + box.ratio),
              horizontal = TRUE,
              origin = NULL, reference = TRUE,
              stack = FALSE,
@@ -155,7 +155,7 @@ panel.barchart <-
                 origin <- current.panel.limits()$xlim[1]
                 reference <- FALSE
             }
-            height <- box.ratio / (1 + box.ratio)
+            height <- box.width # box.ratio / (1 + box.ratio)
         
             if (reference)
                 panel.abline(v = origin,
@@ -189,7 +189,7 @@ panel.barchart <-
             lty <- rep(lty, length = nvals)
             lwd <- rep(lwd, length = nvals)
 
-            height <- box.ratio / (1 + box.ratio)
+            height <- box.width # box.ratio / (1 + box.ratio)
 
             if (reference)
                 panel.abline(v = origin,
@@ -247,7 +247,7 @@ panel.barchart <-
             lty <- rep(lty, length = nvals)
             lwd <- rep(lwd, length = nvals)
 
-            height <- box.ratio/(1 + nvals * box.ratio)
+            height <- box.width / nvals # box.ratio/(1 + nvals * box.ratio)
             if (reference)
                 panel.abline(v = origin,
                              col = reference.line$col,
@@ -281,7 +281,7 @@ panel.barchart <-
                 origin <- current.panel.limits()$ylim[1]
                 reference <- FALSE
             }
-            width <- box.ratio/(1+box.ratio)
+            width <- box.width # box.ratio/(1+box.ratio)
 
             if (reference)
                 panel.abline(h = origin,
@@ -313,7 +313,7 @@ panel.barchart <-
             lty <- rep(lty, length = nvals)
             lwd <- rep(lwd, length = nvals)
 
-            width <- box.ratio/(1 + box.ratio)
+            width <- box.width # box.ratio/(1 + box.ratio)
 
             if (reference)
                 panel.abline(h = origin,
@@ -368,7 +368,7 @@ panel.barchart <-
             lty <- rep(lty, length = nvals)
             lwd <- rep(lwd, length = nvals)
 
-            width <- box.ratio/(1 + nvals * box.ratio)
+            width <- box.width / nvals # box.ratio/(1 + nvals * box.ratio)
             if (reference)
                 panel.abline(h = origin,
                              col = reference.line$col,
@@ -457,7 +457,7 @@ panel.stripplot <-
 
 
 panel.bwplot <-
-    function(x, y, box.ratio = 1,
+    function(x, y, box.ratio = 1, box.width = box.ratio / (1 + box.ratio),
              horizontal = TRUE,
              pch = box.dot$pch,
              col = box.dot$col,
@@ -495,10 +495,10 @@ panel.bwplot <-
                    do.out = do.out)
         blist.stats <- t(sapply(blist, "[[", "stats"))
         blist.out <- lapply(blist, "[[", "out")
-        blist.height <- box.ratio / (1 + box.ratio)
+        blist.height <- box.width # box.ratio / (1 + box.ratio)
         if (varwidth)
         {
-            maxn <- max(by(x, y, length))
+            maxn <- max(table(y))
             blist.n <- sapply(blist, "[[", "n")
             blist.height <- sqrt(blist.n / maxn) * blist.height
         }
@@ -574,10 +574,10 @@ panel.bwplot <-
                    do.out = do.out)
         blist.stats <- t(sapply(blist, "[[", "stats"))
         blist.out <- lapply(blist, "[[", "out")
-        blist.height <- box.ratio / (1 + box.ratio)
+        blist.height <- box.width # box.ratio / (1 + box.ratio)
         if (varwidth)
         {
-            maxn <- max(by(y, x, length))
+            maxn <- max(table(x))
             blist.n <- sapply(blist, "[[", "n")
             blist.height <- sqrt(blist.n / maxn) * blist.height
         }
@@ -664,7 +664,8 @@ panel.bwplot <-
 
 
 panel.violin <-
-    function(x, y, box.ratio = 1, horizontal = TRUE,
+    function(x, y, box.ratio = 1, box.width = box.ratio / (1 + box.ratio),
+             horizontal = TRUE,
 
              alpha = plot.polygon$alpha,
              border = plot.polygon$border,
@@ -727,7 +728,7 @@ panel.violin <-
     
     xscale <- current.panel.limits()$xlim
     yscale <- current.panel.limits()$ylim
-    height <- box.ratio / (1 + box.ratio)
+    height <- box.width # box.ratio / (1 + box.ratio)
 
     if (horizontal)
     {
@@ -792,6 +793,7 @@ dotplot <- function(x, data, ...) UseMethod("dotplot")
 dotplot.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
 {
+    ocall <- sys.call(sys.parent()); ocall[[1]] <- quote(dotplot)
     ccall <- match.call()
     if (!is.null(ccall$data)) 
         warning("explicit 'data' specification ignored")
@@ -799,7 +801,9 @@ dotplot.numeric <-
     ccall$xlab <- xlab
     ccall$x <- ~x
     ccall[[1]] <- quote(lattice::dotplot)
-    eval.parent(ccall)
+    ans <- eval.parent(ccall)
+    ans$call <- ocall
+    ans
 }
 
 
@@ -858,6 +862,7 @@ barchart <- function(x, data, ...) UseMethod("barchart")
 barchart.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
 {
+    ocall <- sys.call(sys.parent()); ocall[[1]] <- quote(barchart)
     ccall <- match.call()
     if (!is.null(ccall$data)) 
         warning("explicit 'data' specification ignored")
@@ -865,7 +870,9 @@ barchart.numeric <-
     ccall$xlab <- xlab
     ccall$x <- ~x
     ccall[[1]] <- quote(lattice::barchart)
-    eval.parent(ccall)
+    ans <- eval.parent(ccall)
+    ans$call <- ocall
+    ans
 }
 
 
@@ -873,14 +880,15 @@ barchart.numeric <-
 
 barchart.table <-
     function(x, data = NULL, groups = TRUE,
-             origin = 0, stack = TRUE, ...)
+             origin = 0, stack = TRUE, ..., horizontal = TRUE)
 {
     if (!is.null(data)) warning("explicit 'data' specification ignored")
     data <- as.data.frame(x)
     nms <- names(data)
     freq <- which(nms == "Freq")
     nms <- nms[-freq]
-    form <- paste(nms[1], "Freq", sep = "~")
+    form <- ## WAS paste(nms[1], "Freq", sep = "~")
+        sprintf(if (horizontal) "%s ~ Freq" else "Freq ~ %s", nms[1])
     nms <- nms[-1]
     len <- length(nms)
     if (is.logical(groups) && groups && len > 0)
