@@ -162,16 +162,14 @@ densityplot <- function(x, data, ...) UseMethod("densityplot")
 densityplot.numeric <-
     function(x, data = NULL, xlab = deparse(substitute(x)), ...)
 {
-    ocall <- ccall <- match.call()
+    ccall <- match.call()
     if (!is.null(ccall$data)) 
         warning("explicit 'data' specification ignored")
     ccall$data <- list(x = x)
     ccall$xlab <- xlab
     ccall$x <- ~x
     ccall[[1]] <- quote(lattice::densityplot)
-    ans <- eval.parent(ccall)
-    ans$call <- ocall
-    ans
+    eval.parent(ccall)
 }
 
 
@@ -286,7 +284,7 @@ densityplot.formula <-
 
     dots <- foo$dots # arguments not processed by trellis.skeleton
     foo <- foo$foo
-    foo$call <- match.call()
+    foo$call <- sys.call(sys.parent()); foo$call[[1]] <- quote(densityplot)
 
     ## Step 2: Compute scales.common (leaving out limits for now)
 
